//
//  YHServerHKLifeViewController.swift
//  galaxy
//
//  Created by EDY on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView

class YHServerHKLifeViewController: YHBaseViewController {

    private let serviceCenterMainReqVM : YHServiceCenterMainViewModel = YHServiceCenterMainViewModel()
    var tableHeadView: YHServerTableHeadView!
    var tableFootView: YHServiceTableFootView!
    var sectionView: YHServiceSectionView!
    
    var homeTableView: UITableView = {
        let tableView = UITableView(frame: .zero, style: .plain)
        tableView.backgroundColor = .clear
        tableView.separatorStyle = .none
        tableView.showsHorizontalScrollIndicator = false
        tableView.showsVerticalScrollIndicator = false
        tableView.rowHeight = UITableView.automaticDimension
        tableView.estimatedRowHeight = 81.0
        tableView.register(YHContractCell.self,forCellReuseIdentifier: YHContractCell.cellReuseIdentifier)
        return tableView
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
        handleRightUI()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        handleRightUI()
        loadData()
    }
}

extension YHServerHKLifeViewController {
    func loadData() {
        if YHLoginManager.shared.isLogin() == false {
            return
        }
        
        serviceCenterMainReqVM.getContactList { success, error in
            if success == true {
                
            } else {
                YHHUD.flash(message: error?.errorMsg ?? "请求出错")
            }
            self.handleRightUI()
        }
    }
    
    func setupUI() {
        gk_navBarAlpha = 0
        gk_navigationBar.isHidden = true
        
        sectionView = {
            let view = YHServiceSectionView()
            return view
        }()
        
        tableHeadView = YHServerTableHeadView()
        tableHeadView.frame = CGRect(x: 0, y: 0, width: KScreenWidth, height: 365)
        tableFootView = YHServiceTableFootView()
        tableFootView.frame = CGRect(x: 0, y: 0, width: KScreenWidth, height: KScreenHeight)
        view.addSubview(homeTableView)
        homeTableView.tableHeaderView = tableHeadView
        homeTableView.tableFooterView = tableFootView
        homeTableView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.bottom.equalToSuperview().offset(-k_Height_TabBar)
        }
        homeTableView.delegate = self
        homeTableView.dataSource = self
        
        
        self.homeTableView.isHidden = true
        
        NotificationCenter.default.addObserver(self, selector: #selector(loginSuccess), name: YhConstant.YhNotification.didLoginSuccessNotifiction, object: nil)
        
        NotificationCenter.default.addObserver(self, selector: #selector(logoutSuccess), name: YhConstant.YhNotification.didLogoutSuccessNotifiction, object: nil)
    }
}

// MARK: - UITableViewDelegate 和 UITableViewDataSource
extension YHServerHKLifeViewController : UITableViewDelegate,UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        
        return 1
    }
    
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return 48
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        return sectionView
    }
    
    func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return 0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
    
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 0.1
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell0 = UITableViewCell()
        return cell0
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
    }
}



extension YHServerHKLifeViewController {
    @objc func loginSuccess() {
        printLog("登录成功，进行相应的 UI刷新操作")
        loadData()
    }
    
    @objc func logoutSuccess() {
        handleRightUI()
    }
    
    private func handleRightUI() {
        if YHLoginManager.shared.isLogin() == false {
            homeTableView.isHidden = true
        } else {
            if serviceCenterMainReqVM.arrContactList.isEmpty {
                homeTableView.isHidden = true
            } else {
                homeTableView.isHidden = false
            }
        }
        homeTableView.reloadData()
    }
}

extension YHServerHKLifeViewController: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
}
